==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/include/dirplaywin.h <==
#ifndef GUARD_dirplaywin_H
#define GUARD_dirplaywin_H
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file dirplaywin.h
/// @brief Class for playlist with directory browser header file.

#include <gtkmm/paned.h>

#include "fixedallocator.h" 

class MainWnd;
class Playlist;

/// @brief Class for playlist with directory browser.
///
/// Class is based on HPaned. Left panel is directory browser.
/// Right panel is playlist.
class DirPlayWnd : public Gtk::HPaned, public SmallObject
{
    public:
	DirPlayWnd(MainWnd& mainWnd, const unsigned int& titleWidth);
	virtual ~DirPlayWnd();

	Playlist* const GetPlaylist();

    private:
	class DirPlayWndImpl;
	std::auto_ptr<DirPlayWndImpl> impl_;	    ///< Implementation of DirPlayWnd

	DirPlayWnd& operator=(const DirPlayWnd&);
	DirPlayWnd(const DirPlayWnd&);
};

#endif

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/dirplaywin.h <==
#ifndef GUARD_dirplaywin_H
#define GUARD_dirplaywin_H
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file dirplaywin.h
/// @brief Class for playlist with directory browser header file.

#include <gtkmm/paned.h>

#include "fixedallocator.h" 

class MainWnd;
class Playlist;

/// @brief Class for playlist with directory browser.
///
/// Class is based on HPaned. Left panel is directory browser.
/// Right panel is playlist.
class DirPlayWnd : public Gtk::HPaned, public SmallObject
{
    public:
	DirPlayWnd(MainWnd& mainWnd, const unsigned int& titleWidth);
	virtual ~DirPlayWnd();

	Playlist* const GetPlaylist();

    private:
	class DirPlayWndImpl;
	const std::auto_ptr<DirPlayWndImpl> impl_;	    ///< Implementation of DirPlayWnd

	DirPlayWnd& operator=(const DirPlayWnd&);
	DirPlayWnd(const DirPlayWnd&);
};

#endif
